@@ -41,6 +41,11 @@ class ICP(BaseAnalysisBlock):
         data_type = ns.dtype_dict[ns.target]
         output = {'icp': {'__mdb_active': False}}
 
+        if 'confidence' in ns.normal_predictions.columns:
+            #  bypass calibrator if model already outputs confidence
+            output['result_df'] = ns.normal_predictions[['confidence', 'lower', 'upper']]
+            return {**info, **output}
+
         fit_params = {'horizon': ns.tss.horizon or 0, 'columns_to_ignore': []}
         fit_params['columns_to_ignore'].extend([f'timestep_{i}' for i in range(1, fit_params['horizon'])])
 
@@ -479,6 +484,13 @@ class ICP(BaseAnalysisBlock):
         elif ns.target_dtype in (dtype.short_text, dtype.rich_text, dtype.binary, dtype.categorical):
             row_insights['prediction'] = row_insights['prediction'].astype(str)
 
+        # horizon collapse
+        if ns.tss.is_timeseries and is_numerical and ns.tss.horizon > 1:
+            row_insights['prediction_sum'] = row_insights['prediction'].apply(lambda x: sum(x))
+            row_insights['lower_sum'] = row_insights['lower'].apply(lambda x: min(x))
+            row_insights['upper_sum'] = row_insights['upper'].apply(lambda x: max(x))
+            row_insights['confidence_mean'] = row_insights['confidence'].apply(lambda x: np.mean(x))
+
         return row_insights, global_insights
 
     @staticmethod
