@@ -1,6 +1,7 @@
+import random
 import torch
 import numpy as np
-import random
+import mxnet as mx
 
 
 def seed(seed_nr: int) -> None:
@@ -9,3 +10,4 @@ def seed(seed_nr: int) -> None:
     torch.backends.cudnn.benchmark = False
     np.random.seed(seed_nr)
     random.seed(seed_nr)
+    mx.random.seed(seed_nr)
